@@ -21,6 +21,7 @@ import re
 from typing import Callable, Union, List, Pattern
 
 import pyrogram
+from pyrogram import enums
 from pyrogram.types import Message, CallbackQuery, InlineQuery, InlineKeyboardMarkup, ReplyKeyboardMarkup, Update
 
 
@@ -126,7 +127,7 @@ def create(func: Callable, name: str = None, **kwargs) -> Filter:
     Custom filters give you extra control over which updates are allowed or not to be processed by your handlers.
 
     Parameters:
-        func (``callable``):
+        func (``Callable``):
             A function that accepts three positional arguments *(filter, client, update)* and returns a boolean: True if the
             update should be handled, False otherwise. 
             The *filter* argument refers to the filter itself and can be used to access keyword arguments (read below). 
@@ -163,7 +164,7 @@ all = create(all_filter)
 
 # region me_filter
 async def me_filter(_, __, m: Message):
-    return bool(m.from_user and m.from_user.is_self or m.outgoing)
+    return bool(m.from_user and m.from_user.is_self or getattr(m, "outgoing", False))
 
 
 me = create(me_filter)
@@ -249,16 +250,6 @@ caption = create(caption_filter)
 
 # endregion
 
-# region edited_filter
-async def edited_filter(_, __, m: Message):
-    return bool(m.edit_date)
-
-
-edited = create(edited_filter)
-"""Filter edited messages."""
-
-
-# endregion
 
 # region audio_filter
 async def audio_filter(_, __, m: Message):
@@ -434,11 +425,22 @@ dice = create(dice_filter)
 """Filter messages that contain :obj:`~pyrogram.types.Dice` objects."""
 
 
+# endregion
+
+# region media_spoiler
+async def media_spoiler_filter(_, __, m: Message):
+    return bool(m.has_media_spoiler)
+
+
+media_spoiler = create(media_spoiler_filter)
+"""Filter media messages that contain a spoiler."""
+
+
 # endregion
 
 # region private_filter
 async def private_filter(_, __, m: Message):
-    return bool(m.chat and m.chat.type in {"private", "bot"})
+    return bool(m.chat and m.chat.type in {enums.ChatType.PRIVATE, enums.ChatType.BOT})
 
 
 private = create(private_filter)
@@ -449,7 +451,7 @@ private = create(private_filter)
 
 # region group_filter
 async def group_filter(_, __, m: Message):
-    return bool(m.chat and m.chat.type in {"group", "supergroup"})
+    return bool(m.chat and m.chat.type in {enums.ChatType.GROUP, enums.ChatType.SUPERGROUP})
 
 
 group = create(group_filter)
@@ -460,7 +462,7 @@ group = create(group_filter)
 
 # region channel_filter
 async def channel_filter(_, __, m: Message):
-    return bool(m.chat and m.chat.type == "channel")
+    return bool(m.chat and m.chat.type == enums.ChatType.CHANNEL)
 
 
 channel = create(channel_filter)
@@ -645,34 +647,34 @@ via_bot = create(via_bot_filter)
 
 # endregion
 
-# region voice_chat_started_filter
-async def voice_chat_started_filter(_, __, m: Message):
-    return bool(m.voice_chat_started)
+# region video_chat_started_filter
+async def video_chat_started_filter(_, __, m: Message):
+    return bool(m.video_chat_started)
 
 
-voice_chat_started = create(voice_chat_started_filter)
-"""Filter messages for started voice chats"""
+video_chat_started = create(video_chat_started_filter)
+"""Filter messages for started video chats"""
 
 
 # endregion
 
-# region voice_chat_ended_filter
-async def voice_chat_ended_filter(_, __, m: Message):
-    return bool(m.voice_chat_ended)
+# region video_chat_ended_filter
+async def video_chat_ended_filter(_, __, m: Message):
+    return bool(m.video_chat_ended)
 
 
-voice_chat_ended = create(voice_chat_ended_filter)
-"""Filter messages for ended voice chats"""
+video_chat_ended = create(video_chat_ended_filter)
+"""Filter messages for ended video chats"""
 
 
 # endregion
 
-# region voice_chat_members_invited_filter
-async def voice_chat_members_invited_filter(_, __, m: Message):
-    return bool(m.voice_chat_members_invited)
+# region video_chat_members_invited_filter
+async def video_chat_members_invited_filter(_, __, m: Message):
+    return bool(m.video_chat_members_invited)
 
 
-voice_chat_members_invited = create(voice_chat_members_invited_filter)
+video_chat_members_invited = create(video_chat_members_invited_filter)
 """Filter messages for voice chat invited members"""
 
 
@@ -689,7 +691,7 @@ service = create(service_filter)
 A service message contains any of the following fields set: *left_chat_member*,
 *new_chat_title*, *new_chat_photo*, *delete_chat_photo*, *group_chat_created*, *supergroup_chat_created*,
 *channel_chat_created*, *migrate_to_chat_id*, *migrate_from_chat_id*, *pinned_message*, *game_score*,
-*voice_chat_started*, *voice_chat_ended*, *voice_chat_members_invited*.
+*video_chat_started*, *video_chat_ended*, *video_chat_members_invited*.
 """
 
 
@@ -740,15 +742,11 @@ async def linked_channel_filter(_, __, m: Message):
 linked_channel = create(linked_channel_filter)
 """Filter messages that are automatically forwarded from the linked channel to the group chat."""
 
+
 # endregion
 
 
 # region command_filter
-
-# Used by the command filter below
-username = None
-
-
 def command(commands: Union[str, List[str]], prefixes: Union[str, List[str]] = "/", case_sensitive: bool = False):
     """Filter commands, i.e.: text messages starting with "/" or any other custom prefix.
 
@@ -771,12 +769,7 @@ def command(commands: Union[str, List[str]], prefixes: Union[str, List[str]] = "
     command_re = re.compile(r"([\"'])(.*?)(?<!\\)\1|(\S+)")
 
     async def func(flt, client: pyrogram.Client, message: Message):
-        # Username shared among all commands; used for mention commands, e.g.: /start@username
-        global username
-
-        if username is None:
-            username = (await client.get_me()).username or ""
-
+        username = client.me.username or ""
         text = message.text or message.caption
         message.command = None
 
